---
Summary: Show scrum board on console
Status: Done
---

# Description

Having a scrum-board like output would vastly improve the experience of Scrum
ceremonies with ScrumMD.

This is going to be in two forms:

`sbl --output board --group-by [something]`

and

`sboard`

The latter will function as an alias for the former, but have default group-by
and columns set separately in the configuration.

We support multiple `group-by` statements, with only the last showing
horizontally. This allows you to use them as 'swim lanes'.
